==> igniteui-react-charts-16.15.1.tgz: package/esm2015/lib/PolarLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { runOn, enumGetBox, markType, markDep } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
export let PolarLineSeries = /*@__PURE__*/ (() => {
    class PolarLineSeries extends PolarLineSeriesBase {
        constructor() {
            super();
            this.ab = PolarLineSeries.$;
        }
        get_dx() {
            return true;
        }
        bv() {
            return new PolarLineSeriesView(this);
        }
        lo(a) {
            super.lo(a);
            this.ur = a;
        }
        up(a) {
            let b = a;
            b.c5();
        }
        uq(a, b) {
            let c = b;
            c.c6(a.m, this.gk);
            this.rt.ax(this, this.sg(), runOn(this, this.q6));
            let d = false;
            let e = this.rt.b;
            if (e != null) {
                d = true;
            }
            if (d) {
                this.tg(-1, this.r2.count, b.q);
            }
            this.rt.ad(b.c8, true, false, true, false);
        }
        uh() {
            return this.us;
        }
        lt(a, b, c, d) {
            super.lt(a, b, c, d);
            switch (b) {
                case PolarLineSeries.$$p[0]:
                    this.l7(false);
                    this.le();
                    break;
            }
        }
    }
    PolarLineSeries.$t = /*@__PURE__*/ markType(PolarLineSeries, 'PolarLineSeries', PolarLineSeriesBase.$);
    PolarLineSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, PolarLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:us:uu', [UnknownValuePlotting_$type, /*@__PURE__*/ enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarLineSeries;
})();
/**
 * @hidden
 */
export let PolarLineSeriesView = /*@__PURE__*/ (() => {
    class PolarLineSeriesView extends PolarLineSeriesBaseView {
        constructor(a) {
            super(a);
            this.c4 = null;
            this.c8 = new Path();
            this.c7 = new Path();
            this.c4 = a;
        }
        as() {
            super.as();
            if (!this.q) {
                this.b1.p0 = Defaults.e;
            }
        }
        c5() {
            this.c8.ak = null;
            this.c7.ak = null;
            this.aq();
        }
        c6(a, b) {
            this.c4.ue.d(this.c8, a, b);
            this.aq();
        }
        bb() {
            super.bb();
        }
        bc() {
            super.bc();
            let a = this.bo();
            this.c7.ak = this.c8.ak;
            this.c7._stroke = a;
            this.c7.ac = this.e.fn + 3;
        }
        a6(a, b) {
            super.a6(a, b);
            if (a.d) {
                if (b) {
                    a.s(this.c7);
                }
                else {
                    a.s(this.c8);
                }
            }
        }
        al(a) {
            super.al(a);
            this.e.a7.exportPathData(a, this.c8, "polarShape", ["Main"]);
        }
    }
    PolarLineSeriesView.$t = /*@__PURE__*/ markType(PolarLineSeriesView, 'PolarLineSeriesView', PolarLineSeriesBaseView.$);
    return PolarLineSeriesView;
})();

==> igniteui-react-charts-16.16.1.tgz: package/esm2015/lib/PolarLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { runOn, enumGetBox, markType, markDep } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
export let PolarLineSeries = /*@__PURE__*/ (() => {
    class PolarLineSeries extends PolarLineSeriesBase {
        constructor() {
            super();
            this.ab = PolarLineSeries.$;
        }
        get_d1() {
            return true;
        }
        bx() {
            return new PolarLineSeriesView(this);
        }
        lz(a) {
            super.lz(a);
            this.vg = a;
        }
        ve(a) {
            let b = a;
            b.c5();
        }
        vf(a, b) {
            let c = b;
            c.c6(a.m, this.ft);
            this.r6.ax(this, this.st(), runOn(this, this.rj));
            let d = false;
            let e = this.r6.b;
            if (e != null) {
                d = true;
            }
            if (d) {
                this.t1(-1, this.sf.count, b.q);
            }
            this.r6.ad(b.c8, true, false, true, false);
        }
        u6() {
            return this.vh;
        }
        l4(a, b, c, d) {
            super.l4(a, b, c, d);
            switch (b) {
                case PolarLineSeries.$$p[0]:
                    this.mi(false);
                    this.lp();
                    break;
            }
        }
    }
    PolarLineSeries.$t = /*@__PURE__*/ markType(PolarLineSeries, 'PolarLineSeries', PolarLineSeriesBase.$);
    PolarLineSeries.$$p = /*@__PURE__*/ markDep(DependencyProperty, PropertyMetadata, PolarLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:vh:vj', [UnknownValuePlotting_$type, /*@__PURE__*/ enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarLineSeries;
})();
/**
 * @hidden
 */
export let PolarLineSeriesView = /*@__PURE__*/ (() => {
    class PolarLineSeriesView extends PolarLineSeriesBaseView {
        constructor(a) {
            super(a);
            this.c4 = null;
            this.c8 = new Path();
            this.c7 = new Path();
            this.c4 = a;
        }
        as() {
            super.as();
            if (!this.q) {
                this.b1.qd = Defaults.e;
            }
        }
        c5() {
            this.c8.ak = null;
            this.c7.ak = null;
            this.aq();
        }
        c6(a, b) {
            this.c4.u3.d(this.c8, a, b);
            this.aq();
        }
        bb() {
            super.bb();
        }
        bc() {
            super.bc();
            let a = this.bo();
            this.c7.ak = this.c8.ak;
            this.c7._stroke = a;
            this.c7.ac = this.e.fu + 3;
        }
        a6(a, b) {
            super.a6(a, b);
            if (a.d) {
                if (b) {
                    a.s(this.c7);
                }
                else {
                    a.s(this.c8);
                }
            }
        }
        al(a) {
            super.al(a);
            this.e.a8.exportPathData(a, this.c8, "polarShape", ["Main"]);
        }
    }
    PolarLineSeriesView.$t = /*@__PURE__*/ markType(PolarLineSeriesView, 'PolarLineSeriesView', PolarLineSeriesBaseView.$);
    return PolarLineSeriesView;
})();
